@@ -1,5 +1,5 @@
 .onAttach <- function(lib, pkg) {
-    packageStartupMessage("EBS Loaded \n")
+    packageStartupMessage("EBS v2.8 Loaded \n")
    
     
 }
